class ScrapingantClientException(Exception):
    """Base class for errors specific to the ScrapingAnt Client."""
    pass


class ScrapingantInvalidTokenException(ScrapingantClientException):
    def __init__(self):
        message = 'API token is wrong or you have exceeded the API calls request limit'
        super().__init__(message)


class ScrapingantInvalidInputException(ScrapingantClientException):
    pass


class ScrapingantSiteNotReachableException(ScrapingantClientException):
    def __init__(self, url):
        message = f'The requested URL is not reachable ({url})'
        super().__init__(message)


class ScrapingantDetectedException(ScrapingantClientException):
    def __init__(self):
        message = 'The anti-bot detection system has detected the request. ' \
                  'Please, retry or change the request settings.'
        super().__init__(message)


class ScrapingantInternalException(ScrapingantClientException):
    def __init__(self):
        message = 'Something went wrong with the server side. Please try later or contact support'
        super().__init__(message)



from typing import List, Optional

from scrapingant_client.cookie import Cookie


class Response:
    def __init__(self, content: str, cookies: List[Cookie], status_code: Optional[int]):
        self.content = content
        self.cookies = cookies
        self.status_code = status_code



from scrapingant_client.headers import convert_headers


def test_convert_empty_headers():
    assert convert_headers(None) is None


def test_convert_headers():
    headers = {
        'User-Agent': 'test',
        'Accept-Language': 'en-US'
    }
    assert convert_headers(headers) == {
        'ant-User-Agent': 'test',
        'ant-Accept-Language': 'en-US'
    }
